@@ -180,24 +180,25 @@ impl TargetOptions {
         let mut s = Vec::with_capacity(4);
 
         if let Some(min_slice) = self.min_slice {
-            s.push(format!("min_slice=={}", min_slice));
+            s.push(format!("min_slice=={min_slice}"));
         }
 
         if let Some(max_slice) = self.max_slice {
-            s.push(format!("max_slice=={}", max_slice));
+            s.push(format!("max_slice=={max_slice}"));
         }
 
         if let Some(use_absolute_max_values) = self.use_absolute_max_values {
-            s.push(format!("use_absolute_max_values=={}", use_absolute_max_values));
+            s.push(format!("use_absolute_max_values=={use_absolute_max_values}"));
         }
 
         if let Some(all) = self.all {
-            s.push(format!("all=={}", all));
+            s.push(format!("all=={all}"));
         }
 
         s.join(", ")
     }
 
+    #[inline]
     fn __repr__(&self) -> String {
         format!(
             "TargetOptions(min_slice={:?}, max_slice={:?}, use_absolute_max_values={:?}, all={:?})",
@@ -247,6 +248,7 @@ impl BasicShotInfo {
 
 #[pymethods]
 impl BasicShotInfo {
+    #[inline]
     fn __str__(&self) -> String {
         match self.shot_type {
             Some(shot_type) => format!("{} shot found at time: {:.2}", shot_type.to_str(), self.time),
@@ -254,6 +256,7 @@ impl BasicShotInfo {
         }
     }
 
+    #[inline]
     fn __repr__(&self) -> String {
         match self.shot_type {
             Some(shot_type) => format!(
@@ -282,6 +285,7 @@ pub struct BallSlice {
 
 #[pymethods]
 impl BallSlice {
+    #[inline]
     fn __str__(&self) -> String {
         format!(
             "Ball @{:.2}s - location: {:?}, velocity: {:?}, angular velocity: {:?}",
@@ -289,6 +293,7 @@ impl BallSlice {
         )
     }
 
+    #[inline]
     fn __repr__(&self) -> String {
         format!(
             "BallSlice(time={}, location={:?}, velocity={:?}, angular_velocity={:?})",
@@ -344,6 +349,7 @@ impl AdvancedShotInfo {
 
 #[pymethods]
 impl AdvancedShotInfo {
+    #[inline]
     fn __str__(&self) -> String {
         if let Some(required_jump_time) = self.required_jump_time {
             format!(
@@ -355,6 +361,7 @@ impl AdvancedShotInfo {
         }
     }
 
+    #[inline]
     fn __repr__(&self) -> String {
         format!(
             "AdvancedShotInfo(final_target={:?}, distance_remaining={}, required_jump_time: {:?}, num_jumps: {:?}, path_samples=[{} items], current_path_point:{:?})",
